@@ -71,7 +71,7 @@ namespace TheSeer\Autoload {
         /**
          * Main executor method
          *
-         * @return void
+         * @return int exit code
          */
         public function run(array $env) {
 
@@ -85,12 +85,12 @@ namespace TheSeer\Autoload {
                 if ($input->getOption('help')->value === TRUE) {
                     $this->showVersion();
                     $this->showUsage();
-                    exit(CLI::RC_OK);
+                    return CLI::RC_OK;
                 }
 
                 if ($input->getOption('version')->value === TRUE ) {
                     $this->showVersion();
-                    exit(CLI::RC_OK);
+                    return CLI::RC_OK;
                 }
 
                 $config = $this->configure($env, $input);
@@ -98,20 +98,20 @@ namespace TheSeer\Autoload {
                 if (!$config->isQuietMode()) {
                     $this->showVersion();
                 }
-                $rc = $this->factory->getApplication()->run();
-                exit($rc);
+
+                return $this->factory->getApplication()->run();
 
             } catch (CLIEnvironmentException $e) {
                 $this->showVersion();
                 fwrite(STDERR, 'Sorry, but your PHP environment is currently not able to run phpab due to');
                 fwrite(STDERR, "\nthe following issue(s):\n\n" . $e->getMessage() . "\n\n");
                 fwrite(STDERR, "Please adjust your PHP configuration and try again.\n\n");
-                exit(CLI::RC_EXEC_ERROR);
+                return CLI::RC_EXEC_ERROR;
             } catch (\ezcConsoleException $e) {
                 $this->showVersion();
                 echo $e->getMessage() . "\n\n";
                 $this->showUsage();
-                exit(CLI::RC_PARAM_ERROR);
+                return CLI::RC_PARAM_ERROR;
             } catch (CollectorException $e) {
                 switch($e->getCode()) {
                     case CollectorException::InFileRedeclarationFound:
@@ -126,11 +126,11 @@ namespace TheSeer\Autoload {
                 }
                 $this->showVersion();
                 fwrite(STDERR, $message . "\n\n");
-                exit(CLI::RC_EXEC_ERROR);
+                return CLI::RC_EXEC_ERROR;
             } catch (\Exception $e) {
                 $this->showVersion();
                 fwrite(STDERR, "\nError while processing request:\n - " . $e->getMessage()."\n");
-                exit(CLI::RC_EXEC_ERROR);
+                return CLI::RC_EXEC_ERROR;
             }
 
         }
